(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('react'), require('@reach/visually-hidden'), require('@reach/tabs'), require('@reach/dialog'), require('react-netlify-identity')) :
  typeof define === 'function' && define.amd ? define(['exports', 'react', '@reach/visually-hidden', '@reach/tabs', '@reach/dialog', 'react-netlify-identity'], factory) :
  (factory((global['react-netlify-identity-widget'] = {}),global.React,global.VisuallyHidden,global.tabs,global.dialog,global.reactNetlifyIdentity));
}(this, (function (exports,React,VisuallyHidden,tabs,dialog,reactNetlifyIdentity) { 'use strict';

  React = React && React.hasOwnProperty('default') ? React['default'] : React;
  VisuallyHidden = VisuallyHidden && VisuallyHidden.hasOwnProperty('default') ? VisuallyHidden['default'] : VisuallyHidden;

  const [useIdentityContext, IdentityContextProvider, IdentityContext] = createUsableCtx();
  const [FormStateContext, FormStateContextProvider] = createMutableCtx("login");
  // utils
  function createMutableCtx(defaultValue) {
      const defaultUpdate = () => defaultValue;
      const ctx = React.createContext({ state: defaultValue, update: defaultUpdate });
      function Provider(props) {
          const [state, update] = React.useState(defaultValue);
          return React.createElement(ctx.Provider, Object.assign({ value: { state, update } }, props));
      }
      return [ctx, Provider];
  }
  function createUsableCtx() {
      const ctx = React.createContext(undefined);
      function useCtx() {
          const c = React.useContext(ctx);
          if (!c)
              throw new Error("useCtx must be inside a Provider with a value");
          return c;
      }
      return [useCtx, ctx.Provider, ctx];
  }

  function useLoading() {
      const [isLoading, setState] = React.useState(false);
      const mount = React.useRef(false);
      React.useEffect(() => {
          mount.current = true;
          return () => void (mount.current = false);
      }, []);
      function load(aPromise) {
          setState(true);
          return aPromise.finally(() => mount.current && setState(false));
      }
      return [isLoading, load];
  }

  function Login() {
      const { loginUser } = useIdentityContext();
      const formRef = React.useRef(null);
      const [msg, setMsg] = React.useState("");
      const [isLoading, load] = useLoading();
      // const signup = () => {
      //   if (!formRef.current) return
      //   const email = formRef.current.email.value
      //   const password = formRef.current.password.value
      //   const data = { signupSource: "react-netlify-identity-widget" }
      //   load(signupUser(email, password, data))
      //     .then(user => {
      //       console.log("Success! Signed up", user)
      //       // navigate("/dashboard")
      //     })
      //     .catch(err => void console.error(err) || setMsg("Error: " + err.message))
      // }
      return (React.createElement("form", { ref: formRef, className: "form", onSubmit: (e) => {
              e.preventDefault();
              const target = e.target;
              const email = target.email.value;
              const password = target.password.value;
              load(loginUser(email, password, true))
                  .then(user => {
                  console.log("Success! Logged in", user);
                  // navigate("/dashboard")
              })
                  .catch(err => void console.error(err) || setMsg("Error: " + err.message));
          } },
          React.createElement("div", { className: "formGroup", key: "email" },
              React.createElement("label", null,
                  React.createElement(VisuallyHidden, null, "Enter your email"),
                  React.createElement("input", { id: "email", className: "formControl", type: "email", name: "email", placeholder: "Email", autoCapitalize: "off", required: true }),
                  React.createElement("div", { className: "inputFieldIcon inputFieldEmail" }))),
          React.createElement("div", { className: "formGroup", key: "password" },
              React.createElement("label", null,
                  React.createElement(VisuallyHidden, null, "Enter your password"),
                  React.createElement("input", { id: "password", className: "formControl", type: "password", name: "password", placeholder: "Password", required: true }),
                  React.createElement("div", { className: "inputFieldIcon inputFieldPassword" }))),
          React.createElement("div", null,
              React.createElement("button", { type: "submit", className: isLoading ? "btn saving" : "btn" }, "Log in"),
              msg && React.createElement("pre", { style: { background: "salmon", padding: 10 } }, msg)),
          React.createElement("button", { type: "button", className: "btnLink forgotPasswordLink" }, "Forgot password?")));
  }

  function Logout() {
      const identity = useIdentityContext();
      const [isLoading, load] = useLoading();
      const logout = () => load(identity.logoutUser());
      return (React.createElement(React.Fragment, null,
          React.createElement("div", { className: "header" },
              React.createElement("button", { className: "btn btnHeader active" }, "Logged in")),
          React.createElement("form", { className: "form " },
              React.createElement("p", { className: "infoText" },
                  "Logged in as ",
                  React.createElement("br", null),
                  React.createElement("span", { className: "infoTextEmail" }, "Shawn Wang")),
              React.createElement("button", { type: "submit", className: isLoading ? "btn saving" : "btn", onClick: logout }, "Log out"))));
  }

  function Signup() {
      const { signupUser } = useIdentityContext();
      const formRef = React.useRef(null);
      const [msg, setMsg] = React.useState("");
      const [isLoading, load] = useLoading();
      const signup = () => {
          if (!formRef.current)
              return;
          const name = formRef.current.username.value;
          const email = formRef.current.email.value;
          const password = formRef.current.password.value;
          const data = { signupSource: "react-netlify-identity-widget", name };
          load(signupUser(email, password, data))
              .then(user => {
              console.log("Success! Signed up", user);
              // navigate("/dashboard")
          })
              .catch(err => void console.error(err) || setMsg("Error: " + err.message));
      };
      return (React.createElement("form", { ref: formRef, className: "form", onSubmit: (e) => {
              e.preventDefault();
              signup();
          } },
          React.createElement("div", { className: "formGroup", key: "username" },
              React.createElement("label", null,
                  React.createElement(VisuallyHidden, null, "Enter your name"),
                  React.createElement("input", { id: "username", className: "formControl", type: "name", name: "username", placeholder: "Name", autoCapitalize: "off", required: true }),
                  React.createElement("div", { className: "inputFieldIcon inputFieldName" }))),
          React.createElement("div", { className: "formGroup", key: "email" },
              React.createElement("label", null,
                  React.createElement(VisuallyHidden, null, "Enter your email"),
                  React.createElement("input", { id: "email", className: "formControl", type: "email", name: "email", placeholder: "Email", autoCapitalize: "off", required: true }),
                  React.createElement("div", { className: "inputFieldIcon inputFieldEmail" }))),
          React.createElement("div", { className: "formGroup", key: "password" },
              React.createElement("label", null,
                  React.createElement(VisuallyHidden, null, "Enter your password"),
                  React.createElement("input", { id: "password", className: "formControl", type: "password", name: "password", placeholder: "Password", required: true }),
                  React.createElement("div", { className: "inputFieldIcon inputFieldPassword" }))),
          React.createElement("div", null,
              React.createElement("button", { type: "submit", className: isLoading ? "btn saving" : "btn" }, "Sign Up"),
              msg && React.createElement("pre", { style: { background: "salmon", padding: 10 } }, msg))));
  }

  // const pagesWithHeader = { login: true, signup: true }
  // const pages = {
  //   login: {
  //     login: true,
  //     button: "Log in",
  //     button_saving: "Logging in",
  //     email: true,
  //     password: true,
  //     link: "amnesia",
  //     link_text: "Forgot password?",
  //     providers: true
  //   },
  //   signup: {
  //     signup: true,
  //     button: "Sign up",
  //     button_saving: "Signing Up",
  //     name: true,
  //     email: true,
  //     password: true,
  //     providers: true
  //   },
  //   amnesia: {
  //     title: "Recover password",
  //     button: "Send recovery email",
  //     button_saving: "Sending recovery email",
  //     email: true,
  //     link: "login",
  //     link_text: "Never mind"
  //   },
  //   recovery: {
  //     title: "Recover password",
  //     button: "Update password",
  //     button_saving: "Updating password",
  //     password: true,
  //     link: "login",
  //     link_text: "Never mind"
  //   },
  //   invite: {
  //     title: "Complete your signup",
  //     button: "Sign up",
  //     button_saving: "Signing Up",
  //     password: true,
  //     providers: true
  //   },
  //   user: {
  //     title: "Logged in"
  //   }
  // }
  function LoggedOutScreen() {
      // return
      return (React.createElement("div", null,
          React.createElement(tabs.Tabs, { defaultIndex: 0 },
              React.createElement(tabs.TabList, { className: "header" },
                  React.createElement(tabs.Tab, { className: "btn btnHeader " }, "Login"),
                  React.createElement(tabs.Tab, { className: "btn btnHeader " }, "Sign Up")),
              React.createElement(tabs.TabPanels, null,
                  React.createElement(tabs.TabPanel, null,
                      React.createElement(Login, null)),
                  React.createElement(tabs.TabPanel, null,
                      React.createElement(Signup, null)))),
          React.createElement("div", { className: "providersGroup" },
              React.createElement("hr", { className: "hr" }),
              React.createElement("button", { className: "providerGoogle btn btnProvider" }, "Continue with Google"),
              React.createElement("button", { className: "providerGitHub btn btnProvider" }, "Continue with GitHub"),
              React.createElement("button", { className: "providerGitLab btn btnProvider" }, "Continue with GitLab"),
              React.createElement("button", { className: "providerBitBucket btn btnProvider" }, "Continue with BitBucket"))));
  }
  function LoggedInScreen() {
      return React.createElement(Logout, null);
  }
  function Gate({}) {
      const identity = useIdentityContext();
      const isLoggedIn = Boolean(identity && identity.user);
      return isLoggedIn ? React.createElement(LoggedInScreen, null) : React.createElement(LoggedOutScreen, null);
  }
  function Widget({ onCloseDialog }) {
      return React.createElement(Gate, { onCloseDialog: onCloseDialog });
  }
  // renderBody() {
  //   const { store } = this.props
  //   const page = pages[store.modal.page] || {}
  //   const pageLinkHandler = () => this.handlePage(page.link)
  //   if (!store.gotrue) {
  //     return <SiteURLForm onSiteURL={this.handleSiteURL} />
  //   }
  //   if (!store.settings) {
  //     return
  //   }
  //   if (store.user) {
  //     return <LogoutForm user={store.user} saving={store.saving} onLogout={this.handleLogout} />
  //   }
  //   if (store.modal.page === "signup" && store.settings.disable_signup) {
  //     return <Message type="signup_disabled" />
  //   }
  //   return (
  //     <div>
  //       <UserForm
  //         page={pages[store.modal.page] || {}}
  //         message={store.message}
  //         saving={store.saving}
  //         onSubmit={this.handleUser}
  //         namePlaceholder={store.namePlaceholder}
  //       />
  //       {!store.user && page.link && store.gotrue && (
  //         <button onclick={pageLinkHandler} className="btnLink forgotPasswordLink">
  //           {page.link_text}
  //         </button>
  //       )}
  //       <SiteURLForm devMode="true" onSiteURL={this.clearSiteURL} />
  //     </div>
  //   )
  // }
  // renderProviders() {
  //   const { store } = this.props
  //   if (!(store.gotrue && store.settings)) {
  //     return null
  //   }
  //   if (store.modal.page === "signup" && store.settings.disable_signup) {
  //     return null
  //   }
  //   const page = pages[store.modal.page] || {}
  //   if (!page.providers) {
  //     return null
  //   }
  //   const providers = ["Google", "GitHub", "GitLab", "BitBucket", "SAML"].filter(
  //     p => store.settings.external[p.toLowerCase()]
  //   )
  //   return providers.length ? (
  //     <Providers
  //       providers={providers}
  //       labels={store.settings.external_labels || {}}
  //       onLogin={this.handleExternalLogin}
  //     />
  //   ) : null
  // }

  const IdentityContextProvider$1 = IdentityContextProvider;
  const useNetlifyIdentity = reactNetlifyIdentity.useNetlifyIdentity;
  const IdentityContext$1 = IdentityContext;
  const useIdentityContext$1 = useIdentityContext;
  function IdentityModal({ showDialog, onCloseDialog }) {
      return (
      // <DialogOverlay isOpen={showDialog}>
      React.createElement(dialog.Dialog, { isOpen: showDialog, onDismiss: () => void console.log("hi") || onCloseDialog(), style: {
              border: "solid 5px hsla(0, 0%, 0%, 0.5)",
              borderRadius: "10px",
              position: "relative",
              maxWidth: 400
          } },
          React.createElement("button", { className: "btn btnClose", onClick: onCloseDialog },
              React.createElement(VisuallyHidden, null, "Close")),
          React.createElement(FormStateContextProvider, null,
              React.createElement(Widget, { onCloseDialog: onCloseDialog }))));
  }

  exports.IdentityContextProvider = IdentityContextProvider$1;
  exports.useNetlifyIdentity = useNetlifyIdentity;
  exports.IdentityContext = IdentityContext$1;
  exports.useIdentityContext = useIdentityContext$1;
  exports.IdentityModal = IdentityModal;

})));
//# sourceMappingURL=reactNetlifyIdentityWidget.umd.development.js.map
